@@ -10,7 +10,7 @@ set -x
 glib-gettextize --copy --force
 libtoolize --automake --copy --force
 intltoolize --automake --copy --force
-aclocal-1.7
+aclocal
 autoconf --force
 autoheader --force
-automake-1.7 --add-missing --copy --force-missing --foreign
+automake --add-missing --copy --force-missing --foreign
