@@ -37,21 +37,12 @@
 #include <http.h>
 
 #include <glib.h>
-#include <gtk/gtk.h>
 
 #include <hildon-home-plugin/hildon-home-plugin-interface.h>
-#include <hildon-widgets/hildon-banner.h>
 #include "weather-home.h"
 
 #include <unistd.h>
 
-#ifndef VERSION
-#define VERSION "0.15"
-#endif
-#ifndef APPNAME
-#define APPNAME "omweather"
-#endif
-
 /* Translate  temperature Celsius to Farenhait */
 int c2f(int temp)
 {
@@ -143,9 +134,9 @@ get_weather_html( gboolean check_connect )
    if (ws->id_station != NULL)
    {
     url = g_string_new (NULL);        
-    g_string_append_printf (url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=10",ws->id_station);
-/*      g_string_append (url,"s=");
-*/    memset(&hExtra, '\0', sizeof(hExtra));
+    g_string_append_printf(url,"http://xoap.weather.com/weather/local/%s?cc=*&prod=xoap&par=1004517364&key=a29796f587f206b2&unit=m&dayf=%d",
+			    ws->id_station, DAY_DOWNLOAD);
+    memset(&hExtra, '\0', sizeof(hExtra));
     hResponse = http_request(url->str,&hExtra,kHMethodGet,HFLAG_NONE);
     g_string_free (url,TRUE);
     if( hResponse.pError || strcmp(hResponse.szHCode,HTTP_RESPONSE_OK) )
@@ -323,7 +314,7 @@ change_station_next (GtkWidget *widget,
 void weather_buttons_init(void){
     int i;
 /* Set default icon N/A */
-    for (i = 0; i < days_to_show; i++){
+    for(i = 0; i < days_to_show; i++){
 	weather_days[i].night.icon = 48;
 	weather_days[i].day.icon = 48;
 	sprintf(weather_days[i].hi_temp, "N/A");
@@ -366,6 +357,8 @@ void weather_buttons_fill(gboolean check_error){
 	    font_size = FONT_MAIN_SIZE_SMALL;
 	    icon_size = 32;
 	}
+
+    
   /* Init weather buttons */
     weather_buttons_init();
     count_day = parse_weather_com_xml();
@@ -393,7 +386,7 @@ void weather_buttons_fill(gboolean check_error){
     add_periodic_event();
 
   /* Search day of saving xml near current day */
-    while ( (offset < Max_count_weather_day) &&
+    while( (offset < Max_count_weather_day) &&
 	    (current_day > weather_days[offset].date_time) &&
 	    (offset<count_day) )
 	offset ++;
@@ -508,13 +501,12 @@ void weather_buttons_fill(gboolean check_error){
 	g_signal_connect(buttons[i], "enter", G_CALLBACK (enter_button), NULL); 
     }/* for */
 
-
     if(g_slist_length(stations_view_list) > 0){
 	tmplist = stations_view_list;
 /* search current station */
         while (tmplist){
     	    ws = tmplist->data;
-	    if (!strcmp(ws->id_station,_weather_station_id)) 
+	    if ((ws->id_station)&&(_weather_station_id) && !strcmp(ws->id_station,_weather_station_id)) 
 		break;
 	    tmplist = g_slist_next(tmplist);
 	}
@@ -525,15 +517,13 @@ void weather_buttons_fill(gboolean check_error){
 	    ws->name_station = NULL;
 	tmp_station_name = NULL;
     }
-    
+
 /* create main panel */
     box = gtk_table_new(2, 1, FALSE);
     create_panel(box, _weather_layout, _enable_transparency, tmp_station_name, font_size);
     gtk_box_pack_start(GTK_BOX(box_zero), box, TRUE, TRUE, 0);
     gtk_widget_show_all(box_zero);
 
-/*     hack_home_plugin_osso_for_nokia800();     */
-    
     if(error_station_code)
 	station_error_window();
 }
@@ -571,7 +561,7 @@ void* hildon_home_applet_lib_initialize(void *state_data,
 					GtkWidget **widget){
     osso_context_t *osso;
     
-    osso = osso_initialize(APPNAME, VERSION, FALSE, NULL);
+    osso = osso_initialize(PACKAGE, VERSION, FALSE, NULL);
     if(!osso){
         g_debug("Error initializing the osso maemo omweather applet");
         return NULL;
@@ -628,7 +618,7 @@ hildon_home_applet_lib_deinitialize(void *applet_data){
 /*    hack_home_plugin_osso_for_nokia800(); */
 }
 
-GtkWidget *
+GtkWidget*
 hildon_home_applet_lib_settings(void *applet_data,
 				 GtkWindow *parent){
     fprintf(stderr, "\nhello-world settings\n");
@@ -694,7 +684,7 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     gtk_label_set_justify(GTK_LABEL(station_name), GTK_JUSTIFY_CENTER);
     set_font_size(station_name, f_size);
     gtk_box_pack_start((GtkBox*) station_box, station_name, TRUE, TRUE, 0);
-    gtk_container_add (GTK_CONTAINER(station_name_btn), station_box);
+    gtk_container_add(GTK_CONTAINER(station_name_btn), station_box);
 /* check transparency */
     if(transparency){
     	gtk_button_set_relief(GTK_BUTTON(previos_station_name_btn), GTK_RELIEF_NONE);
@@ -706,9 +696,9 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     gtk_button_set_focus_on_click(GTK_BUTTON(next_station_name_btn), FALSE);
     gtk_button_set_focus_on_click(GTK_BUTTON(station_name_btn), FALSE);
 /* attach buttons to header panel */
-    gtk_table_attach_defaults( (GtkTable*)header_panel, previos_station_name_btn, 0, 1, 0, 1 );
-    gtk_table_attach_defaults( (GtkTable*)header_panel, station_name_btn, 1, 2, 0, 1 );
-    gtk_table_attach_defaults( (GtkTable*)header_panel, next_station_name_btn, 2, 3, 0, 1 );
+    gtk_table_attach( (GtkTable*)header_panel, previos_station_name_btn, 0, 1, 0, 1 ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
+    gtk_table_attach( (GtkTable*)header_panel, station_name_btn, 1, 2, 0, 1  ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
+    gtk_table_attach( (GtkTable*)header_panel, next_station_name_btn, 2, 3, 0, 1  ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 /* create days panel */
     switch(layout){
 	default:
@@ -730,34 +720,34 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
 	switch(layout){
 	    default:
 	    case ONE_ROW:
-		gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], n, n + 1, 0, 1 );
+		gtk_table_attach( (GtkTable*)days_panel, buttons[n], n, n + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0 );
 	    break;
 	    case ONE_COLUMN:
-		gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], 0, 1, n, n + 1);
+		gtk_table_attach( (GtkTable*)days_panel, buttons[n], 0, 1, n, n + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	    case TWO_ROWS:
 		if(n == elements){
 		    x = 0; y = 1;
 		}
 		if(!y)
-		    gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], x, x + 1, 0, 1);
+		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], x, x + 1, 0, 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		else
-		    gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], x, x + 1, 1, 2);
+		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], x, x + 1, 1, 2,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	    case TWO_COLUMNS:
 		if(n == elements){
 		    x = 0; y = 1;
 		}
 		if(!y)
-		    gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], 0, 1, x, x + 1);
+		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], 0, 1, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 		else
-		    gtk_table_attach_defaults( (GtkTable*)days_panel, buttons[n], 1, 2, x, x + 1);
+		    gtk_table_attach( (GtkTable*)days_panel, buttons[n], 1, 2, x, x + 1,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 	    break;
 	}
     }
 /* attach to main panel header and days panels */
-    gtk_table_attach_defaults( (GtkTable*)panel, header_panel, 0, 1, 0, 1 );
-    gtk_table_attach_defaults( (GtkTable*)panel, days_panel, 0, 1, 1, 2 );
+    gtk_table_attach( (GtkTable*)panel, header_panel, 0, 1, 0, 1 ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
+    gtk_table_attach( (GtkTable*)panel, days_panel, 0, 1, 1, 2 ,(GtkAttachOptions) (0),(GtkAttachOptions) (0), 0, 0);
 /* Connect signal button */
     g_signal_connect (previos_station_name_btn, "released", G_CALLBACK (change_station_prev), NULL);  		    
     g_signal_connect (previos_station_name_btn, "enter", G_CALLBACK (enter_button), NULL); 
@@ -765,6 +755,6 @@ void create_panel(GtkWidget* panel, gint layout, gboolean transparency, gchar* s
     g_signal_connect (next_station_name_btn, "enter", G_CALLBACK (enter_button), NULL); 
     g_signal_connect (station_name_btn, "released", G_CALLBACK (change_station_next), NULL);  		    
     g_signal_connect (station_name_btn, "enter", G_CALLBACK (enter_button), NULL); 
-
+    gtk_container_set_focus_child(GTK_CONTAINER(panel), station_name_btn);
 }
 
