@@ -27,10 +27,9 @@
  * 02110-1301 USA
 	
 */
+#ifndef _weather_home_config_h
+#define _weather_home_config_h 1
 
-#include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <gconf/gconf-client.h>
 #include "weather-home_common.h"
 
 #define GCONF_KEY_PREFIX "/apps/maemo/omweather"
@@ -47,7 +46,9 @@
 #define GCONF_KEY_WEATHER_TEMPERATURE_UNIT GCONF_KEY_PREFIX"/temperature-unit"
 #define GCONF_KEY_WEATHER_LAYOUT           GCONF_KEY_PREFIX"/layout"   
 #define GCONF_KEY_WEATHER_STATIONS_LIST    GCONF_KEY_PREFIX"/station-list"   
-#define GCONF_KEY_WEATHER_DAYS		   GCONF_KEY_PREFIX"/days"
+#define GCONF_KEY_WEATHER_DAYS			GCONF_KEY_PREFIX"/days"
+#define GCONF_KEY_WEATHER_DISTANCE_UNITS	GCONF_KEY_PREFIX"/distance-units"
+#define GCONF_KEY_WEATHER_ICON_SET		GCONF_KEY_PREFIX"/icon-set"
 
 extern gchar    *_weather_dir_name;
 extern gchar    *_weather_country_name;
@@ -63,7 +64,11 @@ extern GSList   *time_update_list;
 extern gchar    _weather_temperature_unit;
 extern int      _weather_layout;
 /* by Pavel */
-extern gint	days_to_show;
+extern	gint	days_to_show;
+extern	gint	distance_units;
+extern	gchar	*icon_set;
+extern	gchar	path_large_icon[_POSIX_PATH_MAX];
 
 gboolean config_set_weather_dir_name(gchar *new_weather_dir_name);
 
+#endif
