@@ -28,12 +28,15 @@
 	
 */
 
+#ifndef _weather_home_parser_h
+#define _weather_home_parser_h 1
+
 #include "weather-home_common.h"
 
-
 extern gchar *_weather_dir_name;
+extern gchar *_weather_station_id;
 
 weather_com_parser *weather_parser_new_from_file(const gchar *filename);
 int parse_weather_com_xml(void);
-extern gchar *_weather_station_id;
 
+#endif
