@@ -29,6 +29,19 @@
 */
 
 #include "weather-home_preference.h"
+#if defined (BSD) && !_POSIX_SOURCE
+    #include <sys/dir.h>
+    typedef struct dirent Dirent;
+#else
+    #include <dirent.h>
+    #include <linux/fs.h>
+    typedef struct dirent Dirent;
+#endif
+/* Hack for Maemo SDK 2.0 */
+#ifndef DT_DIR
+#define DT_DIR 4
+#endif
+
 
 /* Compare station name */
 gint compare_station(gconstpointer a, gconstpointer b){
@@ -75,7 +88,7 @@ void changed_country(void){
     static gchar *gcountry_name = NULL;
     FILE *stations_file, *iso3166_file; 
     char country_name[52];
-    char country_code [2];
+    char country_code [3];
     char temp_state_name[20];
     int count_state = 0; /* Count state of file iso3166 */
 
@@ -283,6 +296,16 @@ static gboolean delete_station(GtkWidget *widget,
       /* Remove station from the Station List */
 	    stations_view_list = g_slist_remove(stations_view_list, ws);
 	    gtk_list_store_clear(station_list_store);
+	    tmplist = stations_view_list;
+
+      /* If not selected station, select first */	    
+	    if (!(gtk_tree_selection_get_selected(selection, NULL, &iter)) && (tmplist != NULL )) {
+	     ws = tmplist->data;
+	     if(_weather_station_id)
+		g_free(_weather_station_id);
+   	     _weather_station_id = g_strdup(ws->id_station); 
+	    }
+	    
 	    fill_station_list_view (station_list_view,station_list_store);
       /* Update station list */
 	    flag_update_station = TRUE;
@@ -335,36 +358,30 @@ static GtkListStore* create_station_list_store(void){
 }
 
 
-static GtkWidget *
-create_tree_view(GtkListStore * list)
-{
-  GtkWidget *tree_view = NULL;
-  GtkTreeSelection *list_selection = NULL;
-  GtkCellRenderer *list_renderer = NULL;
-  GtkTreeViewColumn *list_column = NULL;
+static GtkWidget* create_tree_view(GtkListStore * list){
+    GtkWidget *tree_view = NULL;
+    GtkTreeSelection *list_selection = NULL;
+    GtkCellRenderer *list_renderer = NULL;
+    GtkTreeViewColumn *list_column = NULL;
 
-  /* create the tree view model LIST */
-  tree_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
+/* create the tree view model LIST */
+    tree_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(list));
+/* make the list component single selectable */
+    list_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view));
+    gtk_tree_selection_set_mode(list_selection, GTK_SELECTION_SINGLE);
+/* add name column to the view */
+    list_renderer = gtk_cell_renderer_text_new();
+    list_column = gtk_tree_view_column_new();
+    gtk_tree_view_column_set_sizing(list_column, GTK_TREE_VIEW_COLUMN_FIXED);
+    g_object_set(G_OBJECT(list_renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+    gtk_tree_view_column_set_expand(list_column, TRUE);
 
-  /* make the list component single selectable */
-  list_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_view));
-  gtk_tree_selection_set_mode(list_selection, GTK_SELECTION_SINGLE);
-
-  /* add name column to the view */
-  list_renderer = gtk_cell_renderer_text_new();
-  list_column = gtk_tree_view_column_new();
-  gtk_tree_view_column_set_sizing(list_column, GTK_TREE_VIEW_COLUMN_FIXED);
-  g_object_set(G_OBJECT(list_renderer),
-               "ellipsize", PANGO_ELLIPSIZE_END, NULL);
-  gtk_tree_view_column_set_expand(list_column, TRUE);
-
-  gtk_tree_view_column_pack_start(list_column, list_renderer, TRUE);
-  gtk_tree_view_column_set_attributes(list_column, list_renderer,
+    gtk_tree_view_column_pack_start(list_column, list_renderer, TRUE);
+    gtk_tree_view_column_set_attributes(list_column, list_renderer,
                                       "text", 0, NULL);
-
-  gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), list_column);
-  /* return widget to caller */
-  return tree_view;
+    gtk_tree_view_append_column(GTK_TREE_VIEW(tree_view), list_column);
+/* return widget to caller */
+    return tree_view;
 }
 
 #define ZERO(type, name) type name; memset(&name, 0, sizeof name)
@@ -378,197 +395,163 @@ struct timespec get_time_stamp(void){
     return now;
 }
 
-void
-weather_window_add_custom_station ()
-{
-  struct weather_station *ws;       /* Temp struct for station */
-  GtkWidget *window_add_custom_station;
-  GtkWidget *label;
-  GtkWidget *table;
+void weather_window_add_custom_station(){
+    struct weather_station *ws;       /* Temp struct for station */
+    GtkWidget *window_add_custom_station;
+    GtkWidget *label;
+    GtkWidget *table;
 
-
-  /* Create dialog window */
-  window_add_custom_station = gtk_dialog_new_with_buttons("Add Custom Station",
-            NULL, GTK_DIALOG_MODAL,
-            GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_custom_station)->vbox),
-              table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);	    
-  gtk_dialog_add_button(GTK_DIALOG(window_add_custom_station),
-            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
-  /* Add Custom Station Name  */
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_label_new("Station name:"),
-            0, 1, 0, 1);
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
-            1, 2, 0, 1);
-  gtk_container_add(GTK_CONTAINER(label),custom_station_name = gtk_entry_new());
-  gtk_entry_set_max_length((GtkEntry*)custom_station_name, 16);
-  gtk_entry_set_width_chars((GtkEntry*)custom_station_name, 16);
+/* Create dialog window */
+    window_add_custom_station = gtk_dialog_new_with_buttons("Add Custom Station",
+        							NULL, GTK_DIALOG_MODAL,
+        							GTK_STOCK_OK,
+								GTK_RESPONSE_ACCEPT, NULL);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_custom_station)->vbox),
+        		    table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);	    
+    gtk_dialog_add_button(GTK_DIALOG(window_add_custom_station),
+        		    GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+/* Add Custom Station Name  */
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new("Station name:"),
+        			0, 1, 0, 1);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
+        			1, 2, 0, 1);
+    gtk_container_add(GTK_CONTAINER(label),custom_station_name = gtk_entry_new());
+    gtk_entry_set_max_length((GtkEntry*)custom_station_name, 16);
+    gtk_entry_set_width_chars((GtkEntry*)custom_station_name, 16);
+/* Add Custom Station Code  */
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new("Station code\n (ZIP Code):"),
+        			0, 1, 1, 2);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0.f, 1.f, 0.f, 1.f) ,
+        			1, 2, 1, 2);
+    gtk_container_add(GTK_CONTAINER(label),custom_station_code = gtk_entry_new());	    
+    gtk_entry_set_max_length((GtkEntry*)custom_station_code, 8);
+    gtk_entry_set_width_chars((GtkEntry*)custom_station_code, 8);
   
-  /* Add Custom Station Code  */
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_label_new("Station code\n (ZIP Code):"),
-            0, 1, 1, 2);
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_alignment_new(0.f, 1.f, 0.f, 1.f) ,
-            1, 2, 1, 2);
-  gtk_container_add(GTK_CONTAINER(label),custom_station_code = gtk_entry_new());	    
-  gtk_entry_set_max_length((GtkEntry*)custom_station_code, 8);
-  gtk_entry_set_width_chars((GtkEntry*)custom_station_code, 8);
-  
-
-  gtk_widget_show_all(window_add_custom_station);   
-  
-/* Press Button Ok */
-    while(GTK_RESPONSE_ACCEPT == gtk_dialog_run(GTK_DIALOG(window_add_custom_station))){
-	flag_update_station = TRUE;
-	ws = g_new0(struct weather_station, 1);
-	if(_weather_station_id != NULL)
-	    g_free(_weather_station_id);
-	_weather_station_id = g_strdup(gtk_entry_get_text((GtkEntry*)custom_station_code));
-	ws->id_station = g_strdup(_weather_station_id);
-	if(_weather_station_name != NULL)
-	    g_free(_weather_station_name);
-	_weather_station_name = g_strdup(gtk_entry_get_text((GtkEntry*)custom_station_name));
-	ws->name_station = g_strdup(_weather_station_name);
-
-   /* Add station to stations list */
-	stations_view_list = g_slist_append(stations_view_list, ws); 
-   /* Add station to View List(Tree) */
-	gtk_list_store_clear(station_list_store);
-	fill_station_list_view (station_list_view,station_list_store);
-   /* Update config file */
-	config_save();   
+    gtk_widget_show_all(window_add_custom_station);   
+/* start dialog */
+    switch(gtk_dialog_run(GTK_DIALOG(window_add_custom_station))){
+	case GTK_RESPONSE_ACCEPT:/* Press Button Ok */
+		ws = g_new0(struct weather_station, 1);
+		if(_weather_station_id != NULL)
+		    g_free(_weather_station_id);
+		_weather_station_id = g_strdup(gtk_entry_get_text((GtkEntry*)custom_station_code));
+		ws->id_station = g_strdup(_weather_station_id);
+		if(_weather_station_name != NULL)
+		    g_free(_weather_station_name);
+		_weather_station_name = g_strdup(gtk_entry_get_text((GtkEntry*)custom_station_name));
+		ws->name_station = g_strdup(_weather_station_name);
+	    /* Add station to stations list */
+		stations_view_list = g_slist_append(stations_view_list, ws); 
+	    /* Add station to View List(Tree) */
+		gtk_list_store_clear(station_list_store);
+		fill_station_list_view (station_list_view,station_list_store);
+	    /* Update config file */
+		config_save();
+		flag_update_station = TRUE;
+	break;
+	default:
 	break;
     }
     gtk_widget_destroy(window_add_custom_station);
 }
 
-void
-weather_window_add_station (GtkWidget *widget,
-                               GdkEvent *event,
-                           gpointer user_data)
-{
-  FILE  *iso3166_file;
-  char country_name[52];
+void weather_window_add_station(GtkWidget *widget,
+            			GdkEvent *event,
+                    		gpointer user_data){
+    FILE  *iso3166_file;
+    char country_name[52];
     char out_buffer[1024];   /* Buffer for work with stations.txt files */
-  char flag;                        /* Flag for country processing */
-  int count_country = 0;            /* Count country of file iso3166 */
-  int index_country = 0;            /* Position country of the list */
-  struct weather_station *ws;       /* Temp struct for station */
-  GtkTreeIter iter;                 /* Temp for gtk_combo_box */
-  GtkListStore *country_list_store; /* Country List store */
-  gint result;                      /* Result dialog window */
+    char flag;                        /* Flag for country processing */
+    int count_country = 0;            /* Count country of file iso3166 */
+    int index_country = 0;            /* Position country of the list */
+    struct weather_station *ws;       /* Temp struct for station */
+    GtkTreeIter iter;                 /* Temp for gtk_combo_box */
+    GtkListStore *country_list_store; /* Country List store */
+    GtkWidget *label, *table;
 
-  GtkWidget *label;
-  GtkWidget *table;
-
-  /* Create dialog window */
-  window_add_station = gtk_dialog_new_with_buttons("Add Station",
-            NULL, GTK_DIALOG_MODAL,
-            GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-            NULL);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_station)->vbox),
-            table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);
-  gtk_dialog_add_button(GTK_DIALOG(window_add_station),
-                        "Add Custom Station", OMW_RESPONSE_ADD_CUSTOM_STATION);
-  gtk_dialog_add_button(GTK_DIALOG(window_add_station),
-            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
- 
-  /* Add Country */
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_label_new("Country:"),
-            0, 1, 0, 1);
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
-            1, 2, 0, 1);
-  gtk_container_add(GTK_CONTAINER(label),countrys = gtk_combo_box_new_text());
-
-  /* Add State */
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_label_new("State(Province):"),
-            0, 1, 2, 3);
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
-            1, 2, 2, 3);
+/* Create dialog window */
+    window_add_station = gtk_dialog_new_with_buttons("Add Station",
+        						NULL,
+							GTK_DIALOG_MODAL,
+        						GTK_STOCK_OK,
+							GTK_RESPONSE_ACCEPT, NULL);
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_add_station)->vbox),
+        		table = gtk_table_new(4, 2, FALSE), TRUE, TRUE, 0);
+    gtk_dialog_add_button(GTK_DIALOG(window_add_station),
+                    		"Add Custom Station", OMW_RESPONSE_ADD_CUSTOM_STATION);
+    gtk_dialog_add_button(GTK_DIALOG(window_add_station),
+        			GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
+/* Add Country */
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new("Country:"),
+        			0, 1, 0, 1);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f),
+        			1, 2, 0, 1);
+    gtk_container_add(GTK_CONTAINER(label),countrys = gtk_combo_box_new_text());
+/* Add State */
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new("State(Province):"),
+        			0, 1, 2, 3);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f),
+        			1, 2, 2, 3);
   gtk_container_add(GTK_CONTAINER(label),states = gtk_combo_box_new_text());
+/* Add Station */
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_label_new("Station(Place):"),
+        			0, 1, 3, 4);
+    gtk_table_attach_defaults(GTK_TABLE(table),
+        			label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
+        			1, 2, 3, 4);
+    gtk_container_add(GTK_CONTAINER(label),stations = gtk_combo_box_new_text());
+ 
+    country_list_store = create_station_list_store();
   
-  /* Add Station */
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_label_new("Station(Place):"),
-            0, 1, 3, 4);
-  gtk_table_attach_defaults(GTK_TABLE(table),
-            label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f) ,
-            1, 2, 3, 4);
-  gtk_container_add(GTK_CONTAINER(label),stations = gtk_combo_box_new_text());
-  
-  country_list_store = create_station_list_store();
-  
-  gtk_widget_show_all(window_add_station);   
-
-  /* Inserting Countrys to ComboBox from iso file*/
+    gtk_widget_show_all(window_add_station);   
+/* Inserting Countrys to ComboBox from iso file*/
     flag = FALSE;
-    if((iso3166_file = fopen(COUNTRYS_FILE,"r")) != NULL)
-    {
-     while(!feof(iso3166_file))
-     {
-      memset(out_buffer, 0, sizeof(out_buffer)); /* Clear buffer */
-      fgets(out_buffer, sizeof(out_buffer), iso3166_file); /* Read Next Line */
-      if (strlen(out_buffer)>0){
-       if (streq("----------------------------------------------------------------------\n",out_buffer))
-       {
-        flag = (flag == TRUE) ? FALSE : TRUE ;
-       }
-       else
-       if ( flag == TRUE)
-       {
-         if (strcmp("\n",out_buffer) != 0)
-         {
-          sprintf(country_name,"%.38s",out_buffer);
-
-          gtk_list_store_append(GTK_LIST_STORE
-                              (country_list_store), &iter);
-          gtk_list_store_set(GTK_LIST_STORE(country_list_store),
-                            &iter,
-                            0, country_name,-1);
-
-          count_country++;
-          if ((_weather_country_name != NULL) &&(streq(country_name,_weather_country_name)))
-          {
-           index_country = count_country;
-          }
-         }
-       }
-      }
-     }
-     fclose(iso3166_file);
+    if((iso3166_file = fopen(COUNTRYS_FILE,"r")) != NULL){
+	while(!feof(iso3166_file)){
+	    memset(out_buffer, 0, sizeof(out_buffer)); /* Clear buffer */
+	    fgets(out_buffer, sizeof(out_buffer), iso3166_file); /* Read Next Line */
+	    if(strlen(out_buffer)>0){
+		if(streq("----------------------------------------------------------------------\n",out_buffer))
+    		    flag = (flag == TRUE) ? FALSE : TRUE ;
+		else
+		    if(flag == TRUE){
+    			if(strcmp("\n",out_buffer) != 0){
+    			    sprintf(country_name,"%.38s",out_buffer);
+			    gtk_list_store_append(GTK_LIST_STORE(country_list_store), &iter);
+    			    gtk_list_store_set(GTK_LIST_STORE(country_list_store), &iter,
+                        			0, country_name,-1);
+			    count_country++;
+    			    if((_weather_country_name != NULL) &&(streq(country_name,_weather_country_name)))
+    				index_country = count_country;
+			}
+		    }
+	    }
+	}
+	fclose(iso3166_file);
     }
+    gtk_combo_box_set_model((GtkComboBox*)countrys, (GtkTreeModel*) country_list_store);  
+/* Set default value to country combo_box */
+    if(index_country != 0){
+	gtk_combo_box_set_active (GTK_COMBO_BOX(countrys),index_country-1);
+	changed_country();
+    }
+    g_signal_connect((gpointer)countrys, "changed",
+            		G_CALLBACK (changed_country), NULL);
+    g_signal_connect((gpointer)states, "changed",
+                	G_CALLBACK (changed_state), NULL);
+    g_signal_connect((gpointer) stations, "changed",
+            		G_CALLBACK (changed_stations), NULL);
 
-   gtk_combo_box_set_model((GtkComboBox*)countrys,
-			    (GtkTreeModel*) country_list_store);  
-  
-  
-  /* Set default value to country combo_box */
-  if (index_country != 0)
-  {
-     gtk_combo_box_set_active (GTK_COMBO_BOX(countrys),index_country-1);
-
-     changed_country();
-  }
-
-  g_signal_connect ((gpointer) countrys, "changed",
-                    G_CALLBACK (changed_country),
-                    NULL);
-  g_signal_connect ((gpointer) states, "changed",
-                    G_CALLBACK (changed_state),
-                    NULL);
-  g_signal_connect ((gpointer) stations, "changed",
-                    G_CALLBACK (changed_stations),
-                    NULL);
-
-    result = gtk_dialog_run(GTK_DIALOG(window_add_station));
-    switch(result){
+    switch(gtk_dialog_run(GTK_DIALOG(window_add_station))){
 	default:
 	case GTK_RESPONSE_REJECT:/* Press Cancel  */
 	break;
@@ -576,6 +559,8 @@ weather_window_add_station (GtkWidget *widget,
 	    weather_window_add_custom_station();
 	break;
 	case GTK_RESPONSE_ACCEPT:/* Press Button Ok */
+	    if (gtk_combo_box_get_active(GTK_COMBO_BOX(stations)) == -1) /* Item not selected */
+		break;
 	    flag_update_station = TRUE;
 	    ws = g_new0(struct weather_station,1);
 	    if(_weather_station_id != NULL)
@@ -614,31 +599,36 @@ void weather_window_preference(GtkWidget *widget,
 		*button_del;
 
     char flag_update_icon = '\0'; /* Flag update main weather icon of desktop */
+    gboolean flag_tuning_warning; /* Flag for show the warnings about tuning images of applet */
     int index_update_time = 0; /* Position acive update time of the list */
     GdkColor _weather_font_color_temp; /* Temporary for font color */
     static GSList *time_update_list_temp = NULL; /* Temporary list for time update */
     struct time_update *tu; /* Temporary for time update list */
     char *temp_string;
-    gint	result = ~GTK_RESPONSE_ACCEPT;
    
     not_event = TRUE;
     flag_update_station = FALSE;
     flag_update_icon = FALSE;
+    flag_tuning_warning = FALSE; 
 
     window_config = gtk_dialog_new_with_buttons("Other Maemo Weather Settings",
         				NULL,
 					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
         				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					NULL);
+    /* add CANCEL button */
     gtk_dialog_add_button(GTK_DIALOG(window_config),
             GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
-    /* Create Notebook widget */
+    /* add Help button */
+    gtk_dialog_add_button(GTK_DIALOG(window_config),
+            GTK_STOCK_ABOUT, GTK_RESPONSE_HELP);
+/* Create Notebook widget */
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(window_config)->vbox),
         	    notebook = gtk_notebook_new(), TRUE, TRUE, 0);
-    /* Location page. */
+/* Locations tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         	    table = gtk_table_new(4, 2, FALSE),
-        	    label = gtk_label_new("Location"));
+        	    label = gtk_label_new("Locations"));
 	    
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         	    label = gtk_alignment_new(0.f, 0.f, 0.f, 0.f),
@@ -679,11 +669,11 @@ void weather_window_preference(GtkWidget *widget,
     g_signal_connect(button_add, "clicked",
                 	G_CALLBACK(weather_window_add_station),
                 	NULL);
-    /* Main interface setting page */
+/* Interface tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			table = gtk_table_new(1, 6, FALSE),
-        			label = gtk_label_new("Main Interface"));
-    /* Days to show */
+        			label = gtk_label_new("Interface"));
+/* Days to show */
     days_to_show--; /* count down, because combobox items start with 0 */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
 				label = gtk_label_new("Days to show:"),
@@ -716,7 +706,7 @@ void weather_window_preference(GtkWidget *widget,
 	case 9:  gtk_combo_box_set_active(GTK_COMBO_BOX(days_number), 9);break;
     }    
     days_to_show++; /* count up to return to real value */
-    /* Layout */
+/* Layout */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_label_new("Layout:"),
         			0, 1, 1, 2);
@@ -734,14 +724,24 @@ void weather_window_preference(GtkWidget *widget,
 	case ONE_COLUMN:  gtk_combo_box_set_active(GTK_COMBO_BOX(layout_type),1);break;
 	case TWO_ROWS:  gtk_combo_box_set_active(GTK_COMBO_BOX(layout_type),2);break;
 	case TWO_COLUMNS:  gtk_combo_box_set_active(GTK_COMBO_BOX(layout_type),3);break;
-    }    
-    /* Icon size */
+    }
+    /* Icon set */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
-        			label = gtk_label_new("Icon size:"),
+        			label = gtk_label_new("Icon set:"),
         			0, 1, 2, 3);
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
         			1, 2, 2, 3);
+    gtk_container_add(GTK_CONTAINER(label), iconset = gtk_combo_box_new_text());
+/* add icons set to list */
+    create_icon_set_list(iconset);
+    /* Icon size */
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_label_new("Icon size:"),
+        			0, 1, 3, 4);
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
+        			1, 2, 3, 4);
     gtk_container_add(GTK_CONTAINER(label),icon_size = gtk_combo_box_new_text());
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), "Large");
     gtk_combo_box_append_text(GTK_COMBO_BOX(icon_size), "Medium");
@@ -756,29 +756,33 @@ void weather_window_preference(GtkWidget *widget,
     /* Font color */   
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_label_new("Font color:"),
-        			0, 1, 3, 4);
+        			0, 1, 4, 5);
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
-        			1, 2, 3, 4);
+        			1, 2, 4, 5);
     gtk_container_add(GTK_CONTAINER(label), font_color = gtk_color_button_new());
     gtk_color_button_set_color(GTK_COLOR_BUTTON(font_color), &_weather_font_color);
     /* Transparency */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_label_new("Transparency"),
-        			0, 1, 4, 5);
+        			0, 1, 5, 6);
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f) ,
-        			1, 2, 4, 5);
+        			1, 2, 5, 6);
     gtk_container_add(GTK_CONTAINER(label),chk_transparency = gtk_check_button_new());
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(chk_transparency),
         			    _enable_transparency);
-    /* Temperature unit */
+/* Units tab */
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			table = gtk_table_new(1, 2, FALSE),
+        			label = gtk_label_new("Units"));
+/* Temperature units */
     gtk_table_attach_defaults(GTK_TABLE(table),	    
-        			label = gtk_label_new("Temperature unit:"),
-        			0, 1, 5, 6);
+        			label = gtk_label_new("Temperature units:"),
+        			0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table),	    
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
-        			1, 2, 5, 6);
+        			1, 2, 0, 1);
     gtk_container_add(GTK_CONTAINER(label),temperature_unit = gtk_combo_box_new_text());
     gtk_combo_box_append_text(GTK_COMBO_BOX(temperature_unit), "Celsius (Metric)");
     gtk_combo_box_append_text(GTK_COMBO_BOX(temperature_unit), "Fahrenheit (Imperial)");
@@ -786,12 +790,33 @@ void weather_window_preference(GtkWidget *widget,
 	gtk_combo_box_set_active(GTK_COMBO_BOX(temperature_unit), 0);
     else
 	gtk_combo_box_set_active(GTK_COMBO_BOX(temperature_unit), 1);
-/* Update page */
+/* Distance units */
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+				label = gtk_label_new("Distance units:"),
+				0, 1, 1, 2);
+    gtk_table_attach_defaults(GTK_TABLE(table),	    
+        			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
+				1, 2, 1, 2);
+    gtk_container_add(GTK_CONTAINER(label), units = gtk_combo_box_new_text());
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), "Meters");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), "Kilometers");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), "Miles (International)");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), "Miles (Imperial)");
+    gtk_combo_box_append_text(GTK_COMBO_BOX(units), "Miles (Sea)");
+    switch(distance_units){
+	default:
+	case 0:  gtk_combo_box_set_active(GTK_COMBO_BOX(units), 0);break;
+	case 1:  gtk_combo_box_set_active(GTK_COMBO_BOX(units), 1);break;
+	case 2:  gtk_combo_box_set_active(GTK_COMBO_BOX(units), 2);break;
+	case 3:  gtk_combo_box_set_active(GTK_COMBO_BOX(units), 3);break;
+	case 4:  gtk_combo_box_set_active(GTK_COMBO_BOX(units), 4);break;
+    }    
+/* Update tab */
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
         			table = gtk_table_new(1, 2, FALSE),
         			label = gtk_label_new("Update"));
     gtk_table_attach_defaults(GTK_TABLE(table),
-        			label = gtk_label_new("Update time:"),
+        			label = gtk_label_new("Updating of weather data:"),
         			0, 1, 0, 1);
     gtk_table_attach_defaults(GTK_TABLE(table),
         			label = gtk_alignment_new(0, 0.5, 0.f, 0.f),
@@ -811,43 +836,59 @@ void weather_window_preference(GtkWidget *widget,
 /* kill popup window :-) */
     gtk_widget_destroy(weather_window_popup);
 /* start dialog window */
-    result = gtk_dialog_run(GTK_DIALOG(window_config));
-    switch(result){/* Pressed Button Ok */
-	case GTK_RESPONSE_ACCEPT:
+    switch(gtk_dialog_run(GTK_DIALOG(window_config))){
+	case GTK_RESPONSE_ACCEPT:/* Pressed Button Ok */
+/* icon set */	
+	    if(strcmp(icon_set, gtk_combo_box_get_active_text(GTK_COMBO_BOX(iconset)))){
+	        icon_set = gtk_combo_box_get_active_text(GTK_COMBO_BOX(iconset));
+		memset(path_large_icon, 0, sizeof(path_large_icon));
+		sprintf(path_large_icon, "%s%s/", ICONS_PATH, icon_set);
+		flag_update_icon = TRUE;
+	    }
+/* icon size */	    
 	    if(strcmp(_weather_icon_size, gtk_combo_box_get_active_text(GTK_COMBO_BOX(icon_size))) != 0){
 		_weather_icon_size = gtk_combo_box_get_active_text(GTK_COMBO_BOX(icon_size));
 		flag_update_icon = TRUE;
+		flag_tuning_warning = TRUE;
 	    }
+/* Temperature units */
 	    temp_string = gtk_combo_box_get_active_text(GTK_COMBO_BOX(temperature_unit));
 	    if(_weather_temperature_unit != temp_string[0]){
 		_weather_temperature_unit = temp_string[0];
 		flag_update_icon = TRUE;
 	    }
+/* Font color */
 	    gtk_color_button_get_color(GTK_COLOR_BUTTON(font_color), &_weather_font_color_temp);
-	    if(( _weather_font_color_temp.red != _weather_font_color.red ) &&
-		    ( _weather_font_color_temp.green != _weather_font_color.green ) &&
-		    ( _weather_font_color_temp.blue != _weather_font_color.blue )){
-		_weather_font_color = _weather_font_color_temp;
+	    if(( _weather_font_color_temp.red - _weather_font_color.red ) ||
+		    ( _weather_font_color_temp.green - _weather_font_color.green ) ||
+		    ( _weather_font_color_temp.blue - _weather_font_color.blue )){
+		memcpy(&_weather_font_color, &_weather_font_color_temp, sizeof(_weather_font_color));
     		flag_update_icon = TRUE;
 	    }
-/* by Pavel */
 /* Days to show */
 	    if(gtk_combo_box_get_active((GtkComboBox*)days_number) != days_to_show - 1){
 		days_to_show = gtk_combo_box_get_active((GtkComboBox*)days_number);
 		days_to_show++;
     		flag_update_icon = TRUE;
+		flag_tuning_warning = TRUE;
 	    }
 /* Layout Type */
 	    if(gtk_combo_box_get_active((GtkComboBox*)layout_type) != _weather_layout ){
 		_weather_layout = gtk_combo_box_get_active((GtkComboBox*)layout_type);
     		flag_update_icon = TRUE;
+		flag_tuning_warning = TRUE;
 	    }
 /* Transparency mode */
     	    if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chk_transparency)) != _enable_transparency){
 		_enable_transparency = 
 		    gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(chk_transparency));
     		flag_update_icon = TRUE;
-	    } 
+	    }
+/* Distance units */
+	    if(gtk_combo_box_get_active((GtkComboBox*)units) != distance_units ){
+		distance_units = gtk_combo_box_get_active((GtkComboBox*)units);
+    		flag_update_icon = TRUE;
+	    }
 /* Find select element of update time box and save time value */
 	    time_update_list_temp = time_update_list;
 	    while(time_update_list_temp){
@@ -866,12 +907,13 @@ void weather_window_preference(GtkWidget *widget,
     	    config_save();
 	    if(flag_update_icon)
     		weather_frame_update(FALSE);
-	    if(flag_update_station){
-/*	  update_weather(); */
+	    if(flag_update_station)
     		weather_frame_update(TRUE);
-    	    }
 	    free_list_stations();
 	break;
+	case GTK_RESPONSE_HELP:/* Pressed Button Help */
+	    create_help_dialog();
+	break;
 	default:/* Pressed CANCEL */
 	    if(flag_update_station){
 		if( g_slist_length(stations_view_list) > 0 )
@@ -882,5 +924,121 @@ void weather_window_preference(GtkWidget *widget,
 	break;
     }
     not_event = FALSE;
+    if (flag_tuning_warning)
+    {
+     hildon_banner_show_information(box,NULL,"Use Edit layout \nfor tuning images of applet");    
+    }
     gtk_widget_destroy(window_config);
 }
+/* get icon set names */
+void create_icon_set_list(GtkWidget *store){
+    Dirent	*dp;
+    DIR		*dir_fd;
+    gint	i = 0;
+    
+    dir_fd	= opendir(ICONS_PATH);
+    if(dir_fd){
+	while( (dp = readdir(dir_fd)) ){
+	    if(!strcmp(dp->d_name, ".") || !strcmp(dp->d_name, ".."))
+		continue;
+	    if(dp->d_type == DT_DIR){
+		gtk_combo_box_append_text(GTK_COMBO_BOX(store), dp->d_name);
+		if(!strcmp(icon_set, dp->d_name))
+		    gtk_combo_box_set_active(GTK_COMBO_BOX(store), i);
+		i++;
+	    }
+	}
+	closedir(dir_fd);
+	/* check if selected icon set not found */	
+	if(!gtk_combo_box_get_active_text(GTK_COMBO_BOX(iconset)))
+	    gtk_combo_box_set_active(GTK_COMBO_BOX(store), 0);
+    }
+    else{
+    	gtk_combo_box_append_text(GTK_COMBO_BOX(store), icon_set);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(store), 0);
+    }
+}
+
+void create_help_dialog(void){
+    GtkWidget	*help_dialog,
+		*notebook,
+		*title;
+    char	tmp_buff[2048];
+		    
+    help_dialog = gtk_dialog_new_with_buttons("Other Maemo Weather Info",
+        				NULL,
+					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+        				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					NULL);
+/* Create Notebook widget */
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(help_dialog)->vbox),
+        	    notebook = gtk_notebook_new(), TRUE, TRUE, 0);
+/* About tab */
+    snprintf(tmp_buff, sizeof(tmp_buff), "%s",
+	    "\nHildon desktop applet\n"
+	    "for Nokia 770/800\n"
+	    "to showing forecast weather.\n"
+	    "\nCopyright(c) 2006-2007\n"
+	    "Vlad Vasiliev, Pavel Fialko");
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			create_scrolled_window_with_text(tmp_buff,
+						    GTK_JUSTIFY_CENTER),
+				title = gtk_label_new("About"));
+/* Autohrs tab */
+    snprintf(tmp_buff, sizeof(tmp_buff), "%s",
+		"\nAuthor and maintenance:\n"
+		"\tVlad Vasiliev, vlad@gas.by\n"
+		"Maintenance:\n\tPavel Fialko, pavelnf@gmail.com");
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			create_scrolled_window_with_text(tmp_buff,
+						    GTK_JUSTIFY_LEFT),
+				title = gtk_label_new("Authors"));
+/* Thanks tab */
+    snprintf(tmp_buff, sizeof(tmp_buff), "%s",
+	    "\nEd Bartosh - for support and criticism\n"
+	    "Eugen Kaluta aka tren - for support\n"
+	    "Maxim Kalinkevish aka spark for testing\n"
+	    "Yuri Komyakov - for Nokia 770 device \n"
+	    "Greg Thompson for support stations.txt file\n"
+	    "Frank Persian - for idea of new layout\n"
+	    "Brian Knight - for idea of iconset, criticism \n"
+	    "\t\t\t\tand donation ;-)\n");
+    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+        			create_scrolled_window_with_text(tmp_buff,
+						    GTK_JUSTIFY_LEFT),
+        			title = gtk_label_new("Thanks"));
+    gtk_widget_show_all(help_dialog);
+/* start dialog window */
+    gtk_dialog_run(GTK_DIALOG(help_dialog));
+    gtk_widget_destroy(help_dialog);
+}
+
+GtkWidget* create_scrolled_window_with_text(const char* text,
+				GtkJustification justification){
+
+    GtkWidget	*text_view,
+		*scrolled_window;
+    GtkTextBuffer	*text_buffer;
+
+    text_view = gtk_text_view_new();
+    text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_view));
+    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_buffer), text, -1);
+    /* set params of text view */
+    gtk_text_view_set_editable(GTK_TEXT_VIEW(text_view), FALSE);
+    gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text_view), FALSE);
+    gtk_text_view_set_justification(GTK_TEXT_VIEW(text_view),
+				    justification);
+    gtk_text_view_set_overwrite(GTK_TEXT_VIEW(text_view), FALSE);
+    gtk_text_view_set_accepts_tab(GTK_TEXT_VIEW(text_view), FALSE);
+    gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text_view), GTK_WRAP_NONE);
+    /* scrolled window */
+    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
+					GTK_SHADOW_OUT);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+                                 GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+    gtk_widget_set_size_request(GTK_WIDGET(scrolled_window), 550, 200);
+    /* pack childs to the scrolled window */
+    gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(text_view));
+    return scrolled_window;
+}
